#ifndef AcpiWidget_h
#define AcpiWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Acpi.h"
#include "GridLayoutItem.h"
#include "MainWindow.h"

#include <QBasicTimer>
#include <QLabel>
#include <QProgressBar>
#include <QTimerEvent>

//* battery monitor
namespace Acpi
{

    //* display a set of log entries, allows selection of one
    class AcpiWidget: public MainWindow
    {

        Q_OBJECT

        public:

        //* constructor
        explicit AcpiWidget( QWidget* = nullptr );

        protected:

        //* timer event
        void timerEvent( QTimerEvent* ) override;

        //*@name actions
        //@{

        //* update
        QAction& _updateAction()
        { return *updateAction_; }

        //* label
        QAction& _showLabelAction()
        { return *showLabelAction_; }

        //@}

        //* paint
        void _paint(QPaintDevice&, const QRect&);

        //* context menu
        void _installContextMenuActions( BaseContextMenu* ) override;

        //* tooltip widget
        BaseToolTipWidget* _createToolTipWidget() override;

        //* tooltip
        bool _updateToolTip() override;

        protected Q_SLOTS:

        //* opend configuration dialog
        void _configuration() override;

        //* update configuration
        void _updateConfiguration() override;

        //* toggle show/hide label
        void _toggleLabel( bool );

        //* toggle inverse colors
        void _toggleInverseColors( bool ) override;

        //* update
        void _update();

        protected:

        //* render widget
        void _render( QPaintDevice&, QWidget&, const QRect& );

        private:

        //* install actions
        void _installActions();

        //* acpi
        Acpi acpi_;

        //*@name actions
        //@{

        //* update action
        QAction* updateAction_ = nullptr;

        //* show/hide label
        QAction* showLabelAction_ = nullptr;

        //@}

        //* label
        QLabel* label_ = nullptr;

        //* progress bar
        QProgressBar* progressBar_ = nullptr;

        //* pixmap
        QPixmap battery_;

        //* color map
        using ColorMap = QHash< Acpi::Level, QColor >;
        ColorMap colors_;

        //* pixmap map
        using PixmapMap = QHash< Acpi::State, QPixmap >;

        //* pixmap map
        PixmapMap pixmaps_;

        //@}

        //* tooltip items
        QVector<QLabel*> toolTipItems_;

    };
};

#endif
