#ifndef CalendarEventList_h
#define CalendarEventList_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CalendarEvent.h"
#include "Counter.h"
#include "File.h"

// forward declaration
class XmlDocument;

namespace Calendar
{

    //* store list calendar events
    class CalendarEventList final: private Base::Counter<CalendarEventList>
    {

        public:

        //* constructor
        explicit CalendarEventList():
            Counter( "CalendarEventList" )
        {}

        //* constructor
        explicit CalendarEventList(const CalendarEvent::List& events ):
            Counter( "CalendarEventList" ),
            events_( events )
        {}

        //* read from file
        bool read( File file = File() );

        //* write to file
        bool write( File file = File() ) const;

        //* list
        const CalendarEvent::List& events() const
        { return events_; }

        //* list
        CalendarEvent::List& events()
        { return events_; }

        //* list
        void setEvents( const CalendarEvent::List& events )
        { events_ = events; }

        //* add event
        void add( const CalendarEvent& );

        //* remove event
        void remove( const CalendarEvent& );

        //* replace  event
        void replace( const CalendarEvent& first, const CalendarEvent& second )
        { remove( first ); add( second ); }

        protected:

        //* read events from XmlDocument
        bool _read( const XmlDocument&, CalendarEvent::List& ) const;

        //* differs
        bool _differs( const CalendarEvent::List&, const CalendarEvent::List& ) const;

        private:

        //* associated file where information is to be stored; if any
        File file_;

        //* list of events
        CalendarEvent::List events_;

    };

};

#endif
