/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CalendarEventSmtpClient.h"
#include "Debug.h"

namespace Calendar
{

    //___________________________________________________________________________________________
    CalendarEventSmtpClient::CalendarEventSmtpClient( QObject* parent, const CalendarEvent& event ):
        SmtpClient( parent ),
        event_( event )
    { connect( &_socket(), SIGNAL(error(QAbstractSocket::SocketError)), SLOT(_errorReceived(QAbstractSocket::SocketError)) ); }

    //___________________________________________________________________________________________
    void CalendarEventSmtpClient::_errorReceived( QAbstractSocket::SocketError socketError )
    {
        Debug::Throw() << "CalendarEventSmtpClient::_errorReceived - error: " << socketError << endl;

        // send signal
        emit errorRecieved( event_, _socket().errorString() );

    }

    //___________________________________________________________________________________________
    void CalendarEventSmtpClient::_disconnected()
    {
        Debug::Throw( "CalendarEventSmtpClient::_disconnected.\n" );

        // parent class implementation
        SmtpClient::_disconnected();

        // send signal
        emit errorRecieved( event_, _socket().errorString() );

    }

    //___________________________________________________________________________________________
    void CalendarEventSmtpClient::_messageSent()
    {
        Debug::Throw( "CalendarEventSmtpClient::_messageSent.\n" );

        // parent class implementation
        SmtpClient::_messageSent();

        // send signal
        emit sent( event_ );
    }

}
