#ifndef SmtpClient_h
#define SmtpClient_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QTcpSocket>
#include <QString>
#include <QTextStream>

//* simple smtp interface
namespace Calendar
{
    class SmtpClient : public QObject, private Base::Counter<SmtpClient>
    {
        Q_OBJECT


        public:

        //* constructor
        explicit SmtpClient( QObject* = nullptr );

        //* set host
        void setHost( const QString&, int = 25 );

        //* send mail
        void send( const QString& sender, const QString& recipient, const QString& subject, const QString& body = QString() );

        protected Q_SLOTS:

        //* server state changed
        void _stateChanged( QAbstractSocket::SocketState );

        //* server error
        void _errorReceived( QAbstractSocket::SocketError );

        //* connected to server
        void _connected();

        //* disconnected from server
        void _disconnected();

        //* ready to read
        void _readyRead();

        protected:

        //* message has been sent
        virtual void _messageSent();

        //* socket
        const QTcpSocket& _socket() const
        { return socket_; }

        private:

        //* host
        QString host_;

        //* port
        int port_ = 25;

        //* message to send
        QString message_;

        //* socket
        QTcpSocket socket_;

        //* streamer
        QTextStream stream_;

        //* sender
        QString sender_;

        //*
        QString recipient_;

        //*
        QString response_;

        //* state
        enum State
        {
            Rcpt,
            Mail,
            Data,
            Init,
            Body,
            Quit,
            Close
        };

        //* state
        State state_ = Init;

    };

}
#endif
