#ifndef AlarmDialog_h
#define AlarmDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/**
\file AlarmDialog.h
\brief alarm popup dialog
\author Hugo Pereira
\version $Revision$
\date $Date$
*/

#include "Alarm.h"
#include "TransparentWidget.h"

namespace Clock
{
    //* alarm popup dialog
    class AlarmDialog: public Transparency::TransparentWidget
    {

        Q_OBJECT

        public:

        //* constructor
        explicit AlarmDialog( QWidget*, const Alarm& );

        Q_SIGNALS:

        //* emitted to repeat alarm signal
        void repeat( const Alarm& );

        //* emitted to stop alarm signal
        void closed( const Alarm& );

        protected:

        //* mouse press event [overloaded]
        void mousePressEvent( QMouseEvent* ) override;

        //* mouse press event [overloaded]
        void mouseReleaseEvent( QMouseEvent* ) override;

        //* mouse move event [overloaded]
        void mouseMoveEvent( QMouseEvent* ) override;

        //* paint event
        void _paint( QPaintDevice&, const QRect& ) override;

        //* render widget
        void _render( QPaintDevice&, QWidget&, const QRect& );

        //* current pressed button
        void _setButton( Qt::MouseButton button )
        { button_ = button; }

        //* current pressed button
        Qt::MouseButton _button() const
        { return button_; }

        protected Q_SLOTS:

        //* close
        void _close()
        {
            emit closed( alarm_ );
            Transparency::TransparentWidget::close();
        }

        //* repeat
        void _repeat()
        {
            emit repeat( alarm_ );
            close();
        }

        private:

        //* use svg
        bool useSvg_ = false;

        //* alarm
        const Alarm& alarm_;

        //* click position
        QPoint clickPosition_;

        //* button state
        Qt::MouseButton button_ = Qt::NoButton;

    };

};

#endif
