#ifndef ClockWidget_h
#define ClockWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlarmList.h"
#include "MainWindow.h"

#include <QAction>
#include <QBasicTimer>
#include <QTimerEvent>

//* clock widgets
namespace Clock
{


    //* transparent clock widget
    class ClockWidget: public MainWindow
    {

        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit ClockWidget( QWidget *parent = 0 );

        protected:

        //* context menu
        void _installContextMenuActions( BaseContextMenu* ) override;

        //*@name event handlers
        //@{

        //* enter event
        void enterEvent( QEvent* ) override;

        //* timer event, to toggle repaint
        void timerEvent( QTimerEvent* ) override;

        //* paint event handler
        void _paint( QPaintDevice&, const QRect& );

        //@}

        //* hour color
        const QColor& _hourColor() const
        { return hourColor_; }

        //* hour color
        void _setHourColor( QColor value )
        { hourColor_ = value; }

        //* minutes color
        const QColor& _minuteColor() const
        { return minuteColor_; }

        //* minute color
        void _setMinuteColor( QColor value )
        { minuteColor_ = value; }

        //* seconds color
        const QColor& _secondColor() const
        { return secondColor_; }

        //* second color
        void _setSecondColor( QColor value )
        { secondColor_ = value; }

        protected Q_SLOTS:

        //* repeat
        void _setRepeat( const Alarm& );

        //* repeat
        void _unsetRepeat( const Alarm& );

        //* configuration
        void _configuration() override;

        //* update configuration
        void _updateConfiguration() override;

        //* hours
        void _toggleHourTicks( bool );

        //* minutes
        void _toggleMinuteTicks( bool );

        //* seconds
        void _toggleSeconds( bool );

        //* seconds
        void _toggleDate( bool );

        //* configure alarms
        void _configureAlarms();

        //* adjust time
        void _adjustTime();

        //* toggle inverse colors
        void _toggleInverseColors( bool ) override;

        private:

        //* install actions
        void _installActions();

        //* check alarms
        void _checkAlarms();

        //* hand
        static QPainterPath _hand( int width, int length );

        //* redraw timer
        QBasicTimer timer_;

        //* alarm timer
        /*!
        it is kept separated from the redraw because it only needs to run
        when there are alarms enabled.
        */
        QBasicTimer alarmTimer_;

        //*@name actions
        //@{

        //* ticks
        QAction* showHourTicksAction_;

        //* ticks
        QAction* showMinuteTicksAction_;

        //* seconds
        QAction* showSecondsAction_;

        //* date
        QAction* showDateAction_;

        //* alarms action
        QAction* configureAlarmsAction_;

        //* adjust time action
        QAction* adjustTimeAction_;

        //@}

        //*@name properties
        //@{

        //* hours color
        QColor hourColor_;

        //* minutes color
        QColor minuteColor_;

        //* seconds color
        QColor secondColor_;

        //* hour delay
        int delay_;

        //@}

        //* alarms
        AlarmList alarms_;
    };

}

#endif
