#ifndef CpuMonitor_h
#define CpuMonitor_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CpuLoad.h"
#include "CpuMenu.h"
#include "Counter.h"

#include <QObject>

namespace Cpu
{

    class CpuMonitor: public QObject, private Base::Counter<CpuMonitor>
    {


        //* Qt meta object functions
        Q_OBJECT

        public:

        //* constructor
        explicit CpuMonitor( QObject* = nullptr );

        //*@name accessors
        //@{

        //* menu
        CpuMenu& menu() const
        { return *cpuMenu_; }

        //* device
        const QString& device() const
        { return device_; }

        // network data
        CpuLoad::DataList data() const
        { return cpuLoad_.data( device_ ); }

        //@}

        //*@name modifiers
        //@{

        //* update
        void update()
        { cpuLoad_.update(); }

        //* data size
        void setDataSize( int value )
        { cpuLoad_.setDataSize( value ); }

        //@}

        protected Q_SLOTS:

        //* device
        void _selectDevice( QString );

        private Q_SLOTS:

        //* configuration
        void _updateConfiguration();

        private:

        //* popup menu for cpu name
        CpuMenu* cpuMenu_ = nullptr;

        //* cpu load probe
        CpuLoad cpuLoad_;

        //* cpu name to display
        QString device_;

    };

}

#endif
