/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#ifndef DiskId_h
#define DiskId_h

#include "Counter.h"
#include <QTextStream>

namespace Disk {

    //* disk minor/major number
    class DiskId final: private Base::Counter<DiskId>
    {

        public:

        //* constructor
        explicit DiskId( int major = 0, int minor = 0 ):
            Counter( "DiskId" ),
            major_( major ),
            minor_( minor ),
            valid_( false )
        {};

        //* set minor number
        bool valid() const
        { return valid_; }

        //* hash
        int hash() const
        { return major_<<8 | minor_; }

        private:

        //* major number
        int major_ = 0;

        //* minor number
        int minor_ = 0;

        //* validity
        bool valid_;

        //* load from stream
        friend QTextStream &operator >> ( QTextStream &in, DiskId& id )
        {
            in >> id.major_ >> id.minor_;
            id.valid_ = (in.status() == QTextStream::Ok );
            return in;
        }

        //* write to stream
        friend QTextStream &operator << ( QTextStream &out, const DiskId& id )
        {
            out << "major: " << id.major_ << " minor: " << id.minor_;
            return out;
        }

        //* equal to operator
        friend bool operator == ( const DiskId& first, const DiskId& second )
        { return (first.major_ == second.major_) &&  (first.minor_ == second.minor_); }

        //* lower than operator
        friend bool operator < ( const DiskId& first, const DiskId& second )
        { return ((first.major_  < second.major_) || (first.major_ == second.major_ && first.minor_ < second.minor_) ); }

    };

    //* hash
    inline uint qHash( const DiskId& id )
    { return id.hash(); }

}

#endif
