/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskLoad.h"

#include <QFile>
#include <QStringList>

namespace Disk
{
    //________________________________________________
    DiskLoad::DiskLoad():
        Counter( "DiskLoad" ),
        sampleSize_( 0 ),
        dataSize_( 0 ),
        mountFilename_( "/etc/mtab" )
    { timer_.start(); }

    //________________________________________________
    DiskLoad::DeviceSet DiskLoad::devices( bool mountedOnly )
    {

        update();
        updateMountedDevices();
        DeviceSet out;
        for( auto&& iter = idMap_.begin(); iter != idMap_.end(); ++iter )
        {
            if( !mountedOnly || (mountedOnly && isMounted( iter.key() )) )
            { out.insert( iter.key() ); }
        }

        return out;

    }

    //________________________________________________
    void DiskLoad::updateMountedDevices()
    {

        Debug::Throw( "DiskLoad::updateMountedDevices.\n" );

        // clear old set
        mountedDevices_.clear();

        // open file
        QFile in( mountFilename_ );
        if( !in.open( QIODevice::ReadOnly ) )
        { return; }

        QStringList lines( QString( in.readAll() ).split( "\n" ) );
        for( auto&& line:lines )
        {

            QString device;
            QTextStream stream( &line );
            stream >> device;
            if( stream.status() != QTextStream::Ok ) continue;

            mountedDevices_.insert( device );

        }

    }


    //________________________________________________
    bool DiskLoad::isMounted( const QString& deviceName ) const
    {
        for( const auto& device:mountedDevices_ )
        { if( device.indexOf( deviceName ) >= 0 ) return true; }

        return false;
    }

    //________________________________________________
    QString DiskLoad::toString( double value )
    {

        // add sector size. Assume 512 bytes
        static const double sectorSize = 512;
        value *= sectorSize;

        QString unit( QObject::tr( "bps" ) );
        if( value > 1024 ) { value/=1024; unit = QObject::tr( "kbps" ); }
        if( value > 1024 ) { value/=1024; unit = QObject::tr( "Mbps" ); }
        return QString( "%1 %2" ).arg( QString::number( value, 'f', 1 ),  unit );

    }

}
