#ifndef DiskLoadWrapper_h
#define DiskLoadWrapper_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "DiskLoad_24.h"
#include "DiskLoad_26.h"
#include "KernelVersion.h"

namespace Disk
{

    //* wrapper around kernel dependent disk load measurements
    class DiskLoadWrapper final: private Base::Counter<DiskLoadWrapper>
    {

        public:

        //* constructor
        explicit DiskLoadWrapper():
        Counter( "DiskLoadWrapper" )
        {
            Debug::Throw( "DiskLoadWrapper::DiskLoadWrapper.\n" );
            setKernelVersion( Main::Linux26 );
        }

        //* retrieve singleton
        DiskLoad& get() const
        { return *diskLoad_; }

        //* kernel version
        const Main::KernelVersion& kernelVersion() const
        { return kernel_; }

        //* kernel version
        void setKernelVersion( const Main::KernelVersion& version )
        {
            kernel_ = version;
            switch( kernel_ )
            {

                case Main::Linux24:
                diskLoad_ = &diskLoad24_;
                break;

                default:
                case Main::Linux26:
                diskLoad_ = &diskLoad26_;
                break;

            }
        }

        private:

        //* kernel version
        Main::KernelVersion kernel_;

        //* kernel 2.4 version
        DiskLoad_24 diskLoad24_;

        //* kernel 2.6 version
        DiskLoad_26 diskLoad26_;

        //* current base-class version
        DiskLoad* diskLoad_ = nullptr;

    };

};

#endif
