/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskMonitor.h"
#include "Debug.h"
#include "KernelVersion.h"
#include "Singleton.h"
#include "XmlOptions.h"

namespace Disk
{

    //_____________________________________________
    DiskMonitor::DiskMonitor( QObject* parent ):
        QObject( parent ),
        Counter( "Disk::DiskMonitor" ),
        device_( "hda" )
    {

        // disk menu
        diskMenu_ = new DiskMenu;
        connect( diskMenu_, SIGNAL(deviceSelected(QString)), SLOT(_selectDevice(QString)) );
        diskMenu_->setDevice( device_ );

        connect( Base::Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
        _updateConfiguration();

    }

    //______________________________________________________________________
    void DiskMonitor::_selectDevice( QString device )
    {
        device_ = device;
        XmlOptions::get().set( "DISK_DEVICE", device_ );
    }

    //__________________________________________________________
    void DiskMonitor::_updateConfiguration()
    {
        Debug::Throw( "Disk::DiskMonitor::_updateConfiguration.\n" );

        // kernel version from options
        diskLoad_.setKernelVersion( (Main::KernelVersion) XmlOptions::get().get<int>( "KERNEL_VERSION" ) );
        diskMenu_->setKernelVersion( (Main::KernelVersion) XmlOptions::get().get<int>( "KERNEL_VERSION" ) );

        // samples
        diskLoad_.get().setSampleSize( XmlOptions::get().get<int>( "SAMPLES" ) );

        // device
        diskMenu_->setDevice( device_ = XmlOptions::get().raw( "DISK_DEVICE" ) );

    }

}
