#ifndef DiskMonitor_h
#define DiskMonitor_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "DiskLoadWrapper.h"
#include "DiskMenu.h"
#include "DataSamples.h"

#include <QObject>

//* disk widgets
namespace Disk {

    //* transparent disk load widget
    class DiskMonitor : public QObject, private Base::Counter<DiskMonitor>
    {

        //* Qt meta object functions
        Q_OBJECT

        public:

        //* constructor
        explicit DiskMonitor( QObject* = nullptr );

        //*@name accessors
        //@{

        //* menu
        DiskMenu& menu() const
        { return *diskMenu_; }

        //* device
        const QString& device() const
        { return device_; }

        // network data
        DataSamples::DataList data() const
        { return diskLoad_.get().data( device_ ); }

        //@}

        //*@name modifiers
        //@{

        //* update
        void update()
        { diskLoad_.get().update(); }

        //* data size
        void setDataSize( int value )
        { diskLoad_.get().setDataSize( value ); }

        //@}

        protected Q_SLOTS:

        //* device
        void _selectDevice( QString );


        private Q_SLOTS:

        //* configuration
        void _updateConfiguration();

        private:

        //* popup menu for disk device
        DiskMenu* diskMenu_ = nullptr;

        //* disk load probe
        DiskLoadWrapper diskLoad_;

        //* device
        QString device_;

    };

}

#endif
