#ifndef Application_h
#define Application_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationType.h"
#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "CommandLineParser.h"
#include "Counter.h"

class TransparentWindow;

//* application
class Application: public BaseApplication, private Base::Counter<Application>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit Application( CommandLineArguments );

    //* application type
    void setApplicationType( ApplicationType type )
    { type_ = type; }

    //* create all widgets
    bool realizeWidget() override;

    //* main window
    void setMainWindow( TransparentWindow& top )
    {
        Q_ASSERT( !mainWindow_ );
        mainWindow_ = &top;
    }

    //* main window
    void setMainWindow( TransparentWindow* top )
    {
        Q_ASSERT( !mainWindow_ );
        mainWindow_ = top;
    }

    //* main window
    bool hasMainWindow() const
    { return (bool)mainWindow_; }

    //* main window
    TransparentWindow& mainWindow() const
    {
        Q_CHECK_PTR( mainWindow_ );
        return *mainWindow_;
    }

    //*@name application information
    //@{

    //* command line help
    void usage() const override;

    //* application name
    QString applicationName() const override;

    //* application icon
    QIcon applicationIcon() const override
    { return type_.icon(); }

    // application version
    QString applicationVersion() const override;

    //@}

    Q_SIGNALS:

    //* option recieved
    void optionRecieved( XmlOption );

    public Q_SLOTS:

    //* geometry
    void sendGeometry();

    //* geometry
    void sendOption( XmlOption option );

    //* Send request to all transparency application for raise
    void sendRaiseRequest();

    //* Send request to all transparency application for raise
    void sendCloseRequest();

    protected Q_SLOTS:

    //* process request from application manager
    bool _processCommand( Server::ServerCommand ) override;

    void _configuration()
    {}

    protected:

    //* application type
    const ApplicationType& _type() const
    { return type_; }

    private:

    //* request
    void _sendRequest( Server::ServerCommand::CommandType );

    //* broadcast
    void _broadCast( Server::ServerCommand );

    //* top widget
    TransparentWindow *mainWindow_ = nullptr;

    //* type
    ApplicationType type_ = ApplicationType::AppNone;

};

#endif
