#ifndef MemoryWidget_h
#define MemoryWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "MemoryLoad.h"

#include "GridLayoutItem.h"
#include "HistogramWidget.h"

#include <QAction>
#include <QActionGroup>
#include <QHash>
#include <QPainter>
#include <QTimerEvent>
#include <QBasicTimer>

//* memory widgets
namespace Memory {

    //* transparent memory load widget
    class MemoryWidget : public HistogramWidget
    {

        //* Qt meta object functions
        Q_OBJECT

        public:

        //* constructor
        explicit MemoryWidget( QWidget *parent = nullptr );

        protected:

        //* context menu
        void _installContextMenuActions( BaseContextMenu* ) override;

        //* tooltip widget
        BaseToolTipWidget* _createToolTipWidget() override;

        //* tooltip
        bool _updateToolTip() override;

        //*@name actions
        //@{

        //* auto-scale
        QAction& _autoScaleAction() const
        { return *autoScaleAction_; }

        //@}

        //*@name event handlers
        //@{

        //* timer
        void timerEvent( QTimerEvent* ) override;

        //* paint
        void _paint( QPaintDevice&, const QRect& );

        //* resize event [overloaded]
        void resizeEvent( QResizeEvent* ) override;

        //@}

        protected Q_SLOTS:

        //* opend configuration dialog
        void _configuration() override;

        //* update configuration
        void _updateConfiguration() override;

        //* toggle inverse colors
        void _toggleInverseColors( bool ) override;

        private Q_SLOTS:

        //* toggle auto scale
        void _toggleAutoScale( bool );

        //* toggle display
        void _toggleDisplay( QAction* );

        protected:

        //* update display actions from mask
        void _updateDisplayActions();

        //* scale factor
        double _getScale( const MemoryLoad::DataList& data ) const;

        //* draw load text
        void _paintLoad( QPainter&, QRect& );

        //* set default colors
        void _setDefaultColors();

        private:

        //* install actions
        void _installActions();

        //* memory load probe
        MemoryLoad memoryLoad_;

        //*@name actions
        //@{

        //* auto-scale action
        QAction* autoScaleAction_;

        //* display actions
        QActionGroup* displayActionGroup_;

        //* display actions
        using DisplayActionMap = QHash<QAction*, MemoryLoad::DataType>;

        //* display actions
        DisplayActionMap displayActions_;

        //@}

        //*@name properties
        //@{

        //* display mask
        MemoryLoad::DataTypes displayMask_ = MemoryLoad::All;

        //* color map
        using ColorMap = QHash< MemoryLoad::DataType, Color >;

        //* color map
        ColorMap colorMap_;

        //@}

        //* tooltip items
        GridLayoutItem::List toolTipItems_;

    };
}

#endif
