#ifndef NetworkMenu_h
#define NetworkMenu_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QMenu>
#include <QAction>
#include <QString>
#include <QHash>

namespace Network
{

    /**
    \class NetworkMenu
    \brief customized popup menu to open a previous logbook
    */
    class NetworkMenu: public QMenu, private Base::Counter<NetworkMenu>
    {

        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit NetworkMenu( const QString& = tr( "Select Network Device" ), QWidget* = nullptr );

        //*@name modifiers
        //@{

        //* selected network name
        void setDevice( const QString& value )
        { device_ = value; }

        //* select automatic selection
        void setIsAutomatic( bool value )
        { isAutomatic_ = value; }

        Q_SIGNALS:

        //* signal emited when automatic device selection is triggered
        void automaticDeviceSelected();

        //* signal emited when a device is selected
        void deviceSelected( QString );

        private Q_SLOTS:

        //* select network
        void _select( QAction* );

        //* load list of network devices and update
        void _update();

        private:

        //* selected device
        QString device_;

        //* true if automatic is selected
        bool isAutomatic_ = false;

        //* automation action
        QAction* automaticAction_ = nullptr;

        // action group
        QActionGroup* actionGroup_ = nullptr;

        //* map actions to file recors
        using ActionMap = QHash<QAction*, QString>;

        //* map actions to FileRecords
        ActionMap actions_;

    };

};

#endif
