#ifndef PictureAttributes_h
#define PictureAttributes_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"

#include <QDomDocument>
#include <QDomElement>
#include <QList>
#include <QPoint>
#include <QSize>

//* clock widgets
namespace Pictures
{


    //* transparent clock widget
    class PictureAttributes final: private Base::Counter<PictureAttributes>
    {

        public:

        //* no picture filename
        static const File NoPicture;

        //* list of attributes
        using List = QList<PictureAttributes>;

        //* constructor
        explicit PictureAttributes( const QDomElement& element = QDomElement() );

        //* convert to Xml
        QDomElement domElement( QDomDocument& document ) const;

        //* filename
        const File& filename() const
        { return filename_; }

        //* filename
        bool setFilename( const File& file )
        {
            if( filename_ == file ) return false;
            filename_ = file;
            return true;
        }

        const QPoint& position() const
        { return position_; }

        //* position
        bool setPosition( const QPoint& position )
        {
            if( position_ == position ) return false;
            position_ = position;
            return false;
        }

        //* size
        const QSize& size() const
        { return size_; }

        //* size
        bool setSize( const QSize& size )
        {
            if( size_ == size ) return false;
            size_ = size;
            return true;
        }

        //* visibility
        bool isVisible() const
        { return visible_; }

        //* visibility
        bool setVisible( bool value )
        {
            if( visible_ == value ) return false;
            visible_ = value;
            return true;
        }

        private:

        //* filename
        File filename_ = NoPicture;

        //* position
        QPoint position_;

        //* size
        QSize size_;

        //* visibility
        bool visible_ = true;

    };

    //* less than operator
    bool operator < (const PictureAttributes&, const PictureAttributes&);

    //* equal to operator
    bool operator == (const PictureAttributes&, const PictureAttributes&);


};

#endif
