#ifndef PictureListDialog_h
#define PictureListDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/**
\file PictureListDialog.h
\brief Edit/create pictures
\author Hugo Pereira
\version $Revision$
\date $Date$
*/

#include "CustomDialog.h"
#include "PictureAttributesModel.h"

#include <QPushButton>
#include <QAction>

class TreeView;

namespace Pictures
{
    //* Edit/create alarms
    class PictureListDialog: public CustomDialog
    {


        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit PictureListDialog( QWidget* parent, const PictureAttributes::List& list = PictureAttributes::List() );

        //* picture list
        void setAttributes( const PictureAttributes::List& list );

        //* picture list
        PictureAttributes::List attributes() const;

        private Q_SLOTS:

        //* configuration update
        void _updateConfiguration();

        //* update buttons
        void _updateButtons();

        //* add a value
        void _add();

        //* add a value
        void _edit();

        //* remove a value
        void _remove();

        //* check all
        void _selectAll();

        //* uncheck all
        void _selectNone();

        //* invert selection
        void _invert();

        //* toggle (check/uncheck) item
        void _toggle( const QModelIndex& );

        private:

        //* list
        TreeView& _list() const
        { return *list_; }

        //* model
        PictureAttributesModel& _model()
        { return model_; }

        //* model
        const PictureAttributesModel& _model() const
        { return model_; }

        //* model
        PictureAttributesModel model_;

        //* picture list
        TreeView* list_ = nullptr;

        //* edit button
        QPushButton* edit_ = nullptr;

        //* remove button
        QPushButton* remove_ = nullptr;

        //* select all
        QPushButton* selectAllButton_ = nullptr;

        //* deselect
        QPushButton* selectNoneButton_ = nullptr;

        //* invert
        QPushButton* invertButton_ = nullptr;

        //* remove action
        QAction* removeAction_ = nullptr;

    };

}

#endif
