#ifndef SummaryData_h
#define SummaryData_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "TextFormat.h"

#include <QString>
#include <QPainter>

//* summary widgets
namespace Summary {

    class SummaryData final: private Base::Counter<SummaryData>
    {

        public:

        //* constructor
        explicit SummaryData( const QString& key = QString(), const QString value = QString(), Format::TextFormatFlags format = Format::Default ):
            Counter( "SummaryData" ),
            key_( key ),
            value_( value ),
            format_( format )
        {}

        //* title
        SummaryData& setIsTitle( bool value = true )
        {
            isTitle_ = value;
            return *this;
        }

        //* separator
        SummaryData& setIsSeparator( bool value = true )
        {
            isSeparator_ = value;
            return *this;
        }

        //* horizontal offset
        int horizontalOffset() const
        { return horizontalOffset_; }

        //* horizontal offset
        SummaryData& setHorizontalOffset( int value )
        {
            horizontalOffset_ = value;
            return *this;
        }

        //* full extend
        int valueExtend( QPainter& ) const;

        //* get key extend
        int keyExtend( QPainter& ) const;

        //* paint
        void paint( QPainter&, QRect& ) const;


        //* data list
        using  List = QList<SummaryData>;

        //* paint
        static void paint( List&, QPainter&, QRect& );

        private:

        //* key
        QString key_;

        //* value
        QString value_;

        //* format (for value)
        Format::TextFormatFlags format_ = Format::Default;

        //* title
        bool isTitle_ = false;

        //* separator
        bool isSeparator_ = false;

        //* horizontal offset
        int horizontalOffset_ = 0;

    };

}

#endif
