#ifndef TemperatureMenu_h
#define TemperatureMenu_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Temperature.h"

#include <QMenu>
#include <QAction>
#include <QHash>

namespace Temperature
{

    class TemperatureMenu: public QMenu, private Base::Counter<TemperatureMenu>
    {

        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit TemperatureMenu( const QString& = tr( "Select Temperature Probe Name" ), QWidget *parent = nullptr );

        //* set probe names
        void setDevices( const Temperature::ProbeNames names )
        { devices_ = names; }

        //* selected probe name
        void setDevice( const QString& name )
        { device_ = name; }

        Q_SIGNALS:

        //* signal emited when a probe is selected
        void deviceSelected( QString );

        private Q_SLOTS:

        //* select probe
        void _select( QAction* );

        //* load list of probe names and update
        void _update();

        private:

        Temperature::ProbeNames devices_;

        //* selected probe
        QString device_;

        // action group
        QActionGroup* actionGroup_ = nullptr;

        //* map actions to file recors
        using ActionMap = QHash<QAction*, QString>;

        //* map actions to FileRecords
        ActionMap actions_;

    };

};

#endif
