#ifndef TemperatureWidget_h
#define TemperatureWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TemperatureMonitor.h"
#include "HistogramWidget.h"

#include <QAction>
#include <QPainter>
#include <QBasicTimer>
#include <QTimerEvent>

//* temperature widgets
namespace Temperature
{

    //* transparent temperature load widget
    class TemperatureWidget : public HistogramWidget
    {

        //* Qt meta object functions
        Q_OBJECT

        public:

        //* constructor
        explicit TemperatureWidget( QWidget* = nullptr );

        protected:

        //*@name event handlers
        //@{

        //* timer
        void timerEvent( QTimerEvent* ) override;

        //* paint event [overloaded]
        void _paint( QPaintDevice&, const QRect& );

        //* resize event [overloaded]
        void resizeEvent( QResizeEvent* ) override;

        //@}

        protected Q_SLOTS:

        //* context menu
        void _installContextMenuActions( BaseContextMenu* ) override;

        //* opend configuration dialog
        void _configuration() override;

        //* update configuration
        void _updateConfiguration() override;

        //* toggle inverse colors
        void _toggleInverseColors( bool ) override;

        protected:

        //* scale factor
        double _getScale( const Temperature::DataList& ) const;

        //* draw load text
        void _paintLoad( QPainter&, QRect& );

        //* set default colors
        void _setDefaultColors();

        private:

        //* monitor
        TemperatureMonitor temperatureMonitor_;

        //* popup menu for probe name
        QAction* temperatureMenuAction_ = nullptr;

        //*@name properties
        //@{

        //* foreground color for user bar
        Color temperatureColor_;

        //@}

    };
}

#endif
